==> hyades.ies.sdk.3.0.0_20040331_1118.zip: org/eclipse/hyades/test/http/runner/internal/exec/DomLL.java <==
/*******************************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
/*
 * Created on Oct 15, 2003
 *
 * To change the template for this generated file go to
 * Window&gt;Preferences&gt;Java&gt;Code Generation&gt;Code and Comments
 */

/**
 * @author sdirkers
 *
 * To change the template for this generated type comment go to
 * Window&gt;Preferences&gt;Java&gt;Code Generation&gt;Code and Comments
 */
package org.eclipse.hyades.test.http.runner.internal.exec;

import java.util.LinkedList;

public class DomLL {
	/**
	 *  //This class contains Domain Info to be linked into
	 * //HttpCookieCache LinkedList
	 * 
     *  //Domains can be either a String or an IP Addr
     *  
     */
      public DomLL() 
      {
      	domain = null;
      	isipaddr = false;
      	cookies_stored = 0;
      	UriLL = new LinkedList();
      }  
      	
     /*
      * this constructor makes a Domain LL element with all the info
      */
      public DomLL(String Domain, boolean Ipaddr, int Cookies_stored){
      	 domain = new String(Domain);
      	 isipaddr = Ipaddr;
      	 cookies_stored = Cookies_stored;
      	 UriLL = new LinkedList();
      } 	 
    /*
     * return domain stored
     */
    public String getdomain(){
       return domain;
}
    /*
     * set domain
     */
    public void setdomain(String Domain) {
    	domain = new String(Domain);
    }
    /**
     * get ipaddr flag
     * @return
     */
    public boolean getipaddr() {
    	return isipaddr;
    }
   /*
    * set ippaddr flag
    */
    public void setipaddr(boolean ipaddr) {
    	isipaddr = ipaddr;
    }
    /**
     * get number of cookies stored
     * @return
     */
    public int get_cookies_stored() {
    	return cookies_stored;  	 	      	 
    }
      	 	      	 
    /**
     * return number of cookies stored
     * @param num_cookies
     */
    public void set_cookies_stored(int num_cookies) {
    	cookies_stored = num_cookies;    	 	      	 
    }
      	
    /**
     * return pointer to UriLL linked list
     * @return
     */
    public LinkedList getUriLL() {
    	return UriLL; 	      	 
    }
      	 
      	 // data
      	 	      	 
    public String domain;
    public boolean isipaddr;
    public int cookies_stored;
    public LinkedList UriLL;
    
    
}

==> hyades.ies.sdk.3.0.0_20040525_1708.zip: org/eclipse/hyades/test/http/runner/internal/exec/DomLL.java <==
/*******************************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
/*
 * Created on Oct 15, 2003
 *
 * To change the template for this generated file go to
 * Window&gt;Preferences&gt;Java&gt;Code Generation&gt;Code and Comments
 */

/**
 * @author sdirkers
 *
 * To change the template for this generated type comment go to
 * Window&gt;Preferences&gt;Java&gt;Code Generation&gt;Code and Comments
 */
package org.eclipse.hyades.test.http.runner.internal.exec;

import java.util.LinkedList;

public class DomLL {
	/**
	 *  //This class contains Domain Info to be linked into
	 * //HttpCookieCache LinkedList
	 * 
     *  //Domains can be either a String or an IP Addr
     *  
     */
      public DomLL() 
      {
      	domain = null;
      	isipaddr = false;
      	cookies_stored = 0;
      	UriLL = new LinkedList();
      	iplist = new LinkedList();
      }
      	
     /*
      * this constructor makes a Domain LL element with all the info
      */
      public DomLL(String Domain, boolean Ipaddr, int Cookies_stored){
      	 domain = new String(Domain);
      	 isipaddr = Ipaddr;
      	 cookies_stored = Cookies_stored;
      	 UriLL = new LinkedList();
      	 iplist= new LinkedList();
      } 	 
    /*
     * return domain stored
     */
    public String getdomain(){
       return domain;
}
    /*
     * set domain
     */
    public void setdomain(String Domain) {
    	domain = new String(Domain);
    }
    /**
     * get ipaddr flag
     * @return
     */
    public boolean getipaddr() {
    	return isipaddr;
    }
   /*
    * set ippaddr flag
    */
    public void setipaddr(boolean ipaddr) {
    	isipaddr = ipaddr;
    }
    /**
     * get number of cookies stored
     * @return
     */
    public int get_cookies_stored() {
    	return cookies_stored;  	 	      	 
    }
      	 	      	 
    /**
     * return number of cookies stored
     * @param num_cookies
     */
    public void set_cookies_stored(int num_cookies) {
    	cookies_stored = num_cookies;    	 	      	 
    }
      	
    /**
     * return pointer to UriLL linked list
     * @return
     */
    public LinkedList getUriLL() {
    	return UriLL; 	      	 
    }
      	 
    /**
     * adds an iphost to a list of iphosts on this domain
     */
    public void setreqhost(String host) {
        // assumes host is an ip addr host
    //    System.out.println("adding host =" + host + " to iplist in DomLL");
        iplist.add(host);
      }
    
    /**
     *  returns true or false based on whether an iphost is in the
     * list for this domain
     */
   
    public boolean findip(String iphost) {

        int i;
     //   System.out.println("iplist.size() = " + iplist.size());
        for (i = 0; i < iplist.size(); i++) {
   //       System.out.println("iplist(i) = " + (String)iplist.get(i) + " iphost= " + iphost);
          if (((String)iplist.get(i)).equalsIgnoreCase(iphost))
            return true;
        }
        return false;
    }

    
    
      
      	 // data
      	 	      	 
    public String domain;
    public boolean isipaddr;
    public int cookies_stored;
    public LinkedList UriLL;
    public LinkedList iplist;
    
    
}
